`xoutil.crypto`:mod: - Other cryptographic services
===================================================

.. automodule:: xoutil.crypto
   :members: generate_password, PASS_PHRASE_LEVEL_BASIC,
	     PASS_PHRASE_LEVEL_MAPPED, PASS_PHRASE_LEVEL_MAPPED_MIXED,
	     PASS_PHRASE_LEVEL_MAPPED_DATED, PASS_PHRASE_LEVEL_STRICT,
	     DEFAULT_PASS_PHRASE_LEVEL, MAX_PASSWORD_SIZE
